import React from 'react';

type Upgrades = {
  evenDouble: boolean;
  oddDouble: boolean;
  allTripple: boolean;
  gubbleDouble: boolean;
  addFourthNumber: boolean;
  autoscratcher: boolean;
  swipeScratcher: boolean;
};

type GubbleStoreProps = {
  isOpen: boolean;
  onClose: () => void;
  gubblePoints: number;
  upgrades: Upgrades;
  onBuyUpgrade: (upgrade: keyof Upgrades, cost: number) => void;
};

const UPGRADE_LIST: { key: keyof Upgrades; label: string; cost: number; description: string }[] = [
  { key: 'swipeScratcher', label: 'Swipe Scratcher', cost: 20, description: 'You only need to move the cursor over a tile to scratch it.' },
  { key: 'evenDouble', label: 'Double Even Winnings', cost: 30, description: 'Double winnings from even numbers.' },
  { key: 'gubbleDouble', label: 'Double Gubble Point Gains', cost: 50, description: 'Double gubble point gains.' },
  { key: 'oddDouble', label: 'Double Odd Winnings', cost: 60, description: 'Double winnings from odd numbers.' },
  { key: 'allTripple', label: 'Tripple All Winnings', cost: 150, description: 'Tripple all winnings.' },
  { key: 'addFourthNumber', label: 'Add Fourth Winning Number', cost: 200, description: 'Adds a fourth winning number to each card.' },
  { key: 'autoscratcher', label: 'Auto Scratcher', cost: 400, description: 'Automatically scratches all tiles when you buy a card.' },
];

const GubbleStore: React.FC<GubbleStoreProps> = ({ isOpen, onClose, gubblePoints, upgrades, onBuyUpgrade }) => {
  if (!isOpen) return null;
  return (
    <div className="fixed inset-0 bg-black bg-opacity-80 flex items-center justify-center z-50">
      <div className="bg-gray-900 rounded-lg shadow-lg p-8 w-full max-w-md relative">
        <button className="absolute top-2 right-2 text-gray-400 hover:text-gray-200 text-2xl" onClick={onClose}>&times;</button>
        <h2 className="text-2xl font-bold mb-4 text-blue-300">Gubble Point Store</h2>
        <div className="mb-4 text-gray-100">Gubble Points: <span className="font-mono font-bold">{gubblePoints}</span></div>
        <div><p className="text-gray-400 text-sm mb-4">When you buy an upgrade, you will lose all your money and unlocked tiers. And return to the start with the upgrades enabled.</p></div>
        <ul className="space-y-4">
          {UPGRADE_LIST.map(upg => (
            <li key={upg.key} className="flex flex-col sm:flex-row sm:items-center sm:justify-between bg-gray-800 rounded p-3 border border-gray-700">
              <div>
                <div className="font-semibold text-lg text-gray-100">{upg.label}</div>
                <div className="text-gray-400 text-sm mb-1">{upg.description}</div>
                <div className="text-gray-300 text-sm">Cost: <span className="font-mono">{upg.cost}</span></div>
              </div>
              <button
                className={`mt-2 sm:mt-0 px-4 py-1 rounded font-bold text-white ${upgrades[upg.key] ? 'bg-green-300 cursor-not-allowed' : gubblePoints < upg.cost ? 'bg-red-500 cursor-not-allowed' : 'bg-blue-700 hover:bg-blue-800'}`}
                disabled={upgrades[upg.key] || gubblePoints < upg.cost}
                onClick={() => onBuyUpgrade(upg.key, upg.cost)}
              >
                {upgrades[upg.key] ? 'Bought' : 'Buy'}
              </button>
            </li>
          ))}
        </ul>
      </div>
    </div>
  );
};

export type { Upgrades };
export default GubbleStore; 