import React from 'react';
import type { Upgrades } from './GubbleStore';
import type { CardProps } from './Card';

const ScratchFieldButton: React.FC<{
  field: { value: number; scratched: boolean; won: number | null };
  idx: number;
  card: CardProps['card'];
  setCard: CardProps['setCard'];
  setMoney: CardProps['setMoney'];
  setGubblePoints: CardProps['setGubblePoints'];
  upgrades?: Upgrades;
  formatter: Intl.NumberFormat;
}> = ({ field, idx, card, setCard, setMoney, setGubblePoints, upgrades, formatter }) => {
  const handleMouseMove = () => {
    if (field.scratched) return;
    if (upgrades?.swipeScratcher) {
      handleScratch();
    }
  }
  const handleScratch = () => {
    if (field.scratched) return;
    // Gubble point gain (with upgrade)
    if (Math.random() < (card.tier?.gubblePointChance ?? 0)) {
      setGubblePoints((g) => g + (upgrades?.gubbleDouble ? 2 : 1));
    }
    // Determine win amount
    let won = null;
    if (card.winningNumbers.includes(field.value)) {
      won = 0;
      if (idx < 2) won = Math.ceil((card.tier?.buyPrice ?? 0) * 0.5);
      else if (idx < 4) won = Math.ceil((card.tier?.buyPrice ?? 0) * 0.8);
      else won = Math.ceil((card.tier?.buyPrice ?? 0) * 1.2);
      // Apply upgrades
      if (upgrades?.allTripple) {
        won = won * 2;
      } 
      if (upgrades?.evenDouble && field.value % 2 === 0) {
        won = won * 2;
      } 
      if (upgrades?.oddDouble && field.value % 2 === 1) {
        won = won * 2;
      }
    }
    setCard((prev) => {
      if (!prev) return prev;
      const newFields = prev.fields.map((f, i) => i === idx ? { ...f, scratched: true, won } : f);
      return { ...prev, fields: newFields };
    });
    if (won) setMoney((m) => m + won);
  };
  if (upgrades?.autoscratcher) {
    handleScratch();
  }

  return (
    <button
      className={`w-16 h-16 flex items-center justify-center rounded-lg border-2 text-2xl font-bold transition
        ${field.scratched ? (field.won ? 'bg-green-900 border-green-700 text-green-300' : 'bg-gray-700 border-gray-600 text-gray-400') : 'bg-yellow-900 border-yellow-700 text-yellow-300 hover:bg-yellow-800'}`}
      disabled={field.scratched}
      onClick={handleScratch}
      onMouseMove={handleMouseMove}
    >
      {field.scratched ? (
        <span>{field.value}{field.won ? <span className="block text-xs font-normal text-green-300">+${formatter.format(field.won)}</span> : ''}</span>
      ) : (
        <span className="text-3xl select-none">?</span>
      )}
    </button>
  );
};

export default ScratchFieldButton; 